[jboss-cvs] JBossAS SVN: r59136 - projects/microcontainer/trunk/container/src/main/org/jboss/joinpoint/plugins

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Tue Dec 19 05:33:56 EST 2006


Author: alesj
Date: 2006-12-19 05:33:54 -0500 (Tue, 19 Dec 2006)
New Revision: 59136

Modified:
   projects/microcontainer/trunk/container/src/main/org/jboss/joinpoint/plugins/Config.java
Log:
javadoc, exc. on null classInfo

Modified: projects/microcontainer/trunk/container/src/main/org/jboss/joinpoint/plugins/Config.java
===================================================================
--- projects/microcontainer/trunk/container/src/main/org/jboss/joinpoint/plugins/Config.java	2006-12-19 10:24:50 UTC (rev 59135)
+++ projects/microcontainer/trunk/container/src/main/org/jboss/joinpoint/plugins/Config.java	2006-12-19 10:33:54 UTC (rev 59136)
@@ -259,6 +259,8 @@
     */
    public static FieldInfo findFieldInfo(ClassInfo classInfo, String name) throws JoinpointException
    {
+      if (classInfo == null)
+         throw new IllegalArgumentException("ClassInfo cannot be null!");
       ClassInfo current = classInfo;
       while (current != null)
       {
@@ -273,7 +275,7 @@
    /**
     * Find field info
     *
     * @param fieldInfo the field info
     * @param name the field name
     * @return the field info or null if not found
     */
@@ -318,6 +320,9 @@
     */
    public static MethodInfo findMethodInfo(ClassInfo classInfo, String name, String[] paramTypes, boolean isStatic, boolean isPublic) throws JoinpointException
    {
+      if (classInfo == null)
+         throw new IllegalArgumentException("ClassInfo cannot be null!");
+
       if (paramTypes == null)
          paramTypes = NO_PARAMS_TYPES;
 
@@ -273,7 +275,7 @@
     * Find field info
     *
-    * @param fieldInfo the field info
+    * @param classInfo the class info
     * @param name the field name
     * @return the field info or null if not found




More information about the jboss-cvs-commits mailing list